@@ -35,7 +35,7 @@
 #include "xap_UnixFontXLFD.h"
 
 #include "ut_AdobeEncoding.h"
-
+#include "ut_string_class.h"
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include <X11/Xft/Xft.h>
@@ -106,7 +106,7 @@ class ABI_EXPORT XAP_UnixFont
 	void					setXLFD(const char * xlfd);
 	const char * 			getXLFD(void) const;
 	bool                    isSymbol(void)
-		{ return m_bIsSymbol;}	
+		{ return m_bIsSymbol;}
 	bool					embedInto(ps_Generate& ps);
 	bool					openPFA(void);
 	char					getPFAChar(void);
@@ -128,8 +128,13 @@ class ABI_EXPORT XAP_UnixFont
 	void					setFontManager(XAP_UnixFontManager * pFm);
 	
 	bool doesGlyphExist(UT_UCS4Char g);
-
+	bool                    isSymbol(void) const;
+	bool                    isDingbat(void) const;
 private:
+
+	XAP_UnixFont ();
+	XAP_UnixFont & operator= (const XAP_UnixFont & rhs);
+
 	bool					_createTtfSupportFiles();
 	bool					_createPsSupportFiles();
 	struct allocFont
@@ -142,11 +147,11 @@ private:
 	char * 					m_fontKey;
 
 	// a cache of XftFont * at a given size
-	mutable UT_Vector		m_allocFonts;
+	mutable UT_GenericVector<allocFont *>	m_allocFonts;
 	
 	char * 					m_name;
 	XAP_UnixFont::style		m_style;
-	char * 					m_xlfd;
+	UT_String    			m_xlfd;
 	
 	// The next line is the info that is given back to us by parseAFM. The line after that is our own mangled one to follow Unicode.
 	uniWidth *				m_uniWidths;
@@ -201,6 +206,8 @@ class XAP_UnixFontHandle : public GR_Font
 
 	XAP_UnixFontHandle(XAP_UnixFont * font, UT_uint32 size);	
  
+	virtual ~XAP_UnixFontHandle () {}
+
 	XftFont * 					getLayoutXftFont(void);
 	XftFont * 					getDeviceXftFont(UT_uint32 zoomPercentage);
 
@@ -218,6 +225,9 @@ class XAP_UnixFontHandle : public GR_Font
 
 private:
  	XAP_UnixFontHandle();
+ 	XAP_UnixFontHandle(const XAP_UnixFontHandle & rhs);
+ 	XAP_UnixFontHandle & operator=(const XAP_UnixFontHandle & rhs);
+
 	XAP_UnixFont*				m_font;
 	UT_uint32					m_size;
 };
