@@ -21,8 +21,6 @@
  * 02111-1307, USA.
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdk.h>
@@ -206,7 +204,9 @@ abi_table_embed_on_toolbar (AbiTable* abi_table, GtkToolbar* toolbar)
 		gtk_widget_hide(abi_table->label);
 #endif
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
-	gtk_toolbar_append_widget (toolbar, GTK_WIDGET(abi_table), pSS->getValueUTF8(XAP_STRING_ID_TB_InsertNewTable).utf8_str(), NULL);
+	UT_UTF8String s;
+	pSS->getValueUTF8(XAP_STRING_ID_TB_InsertNewTable,s);
+	gtk_toolbar_append_widget (toolbar, GTK_WIDGET(abi_table), s.utf8_str(), NULL);
 }
 
 static gboolean
@@ -456,9 +456,7 @@ on_pressed(GtkButton* button, gpointer user_data)
 	popup_grab_on_window (GTK_WIDGET(table->area)->window,
 			      gtk_get_current_event_time ());
 
-	selected_color.red = 0;
-	selected_color.green = 0;
-	selected_color.blue = 0x8000;
+	selected_color = (GTK_WIDGET (button))->style->base[GTK_STATE_SELECTED];
 
 	/* leak */
 	table->selected_gc = gdk_gc_new(GTK_WIDGET(button)->window);
@@ -652,7 +650,9 @@ abi_table_init (AbiTable* table)
 {
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 	UT_UTF8String prText =  "%d x %d ";
-	prText += pSS->getValueUTF8(XAP_STRING_ID_TB_Table);
+	UT_UTF8String s;
+	pSS->getValueUTF8(XAP_STRING_ID_TB_Table,s);
+	prText += s;
 	char* text = g_strdup_printf(prText.utf8_str(), init_rows, init_cols);
 
 	register_stock_icon();
