@@ -29,6 +29,7 @@ BeginLayout(Main,0)
 
 	BeginSubMenu(AP_MENU_ID_FILE)
 		MenuItem(AP_MENU_ID_FILE_NEW)
+		MenuItem(AP_MENU_ID_FILE_NEW_USING_TEMPLATE)
 		MenuItem(AP_MENU_ID_FILE_OPEN)
 		MenuItem(AP_MENU_ID_FILE_SAVE)
 		MenuItem(AP_MENU_ID_FILE_SAVEAS)
@@ -77,6 +78,10 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_EDIT_FIND)
 		MenuItem(AP_MENU_ID_EDIT_REPLACE)
 		MenuItem(AP_MENU_ID_EDIT_GOTO)
+#if !(XAP_PREFSMENU_UNDER_TOOLS)
+		Separator()
+		MenuItem(AP_MENU_ID_TOOLS_OPTIONS)
+#endif
 	EndSubMenu()
 
 	BeginSubMenu(AP_MENU_ID_VIEW)
@@ -124,6 +129,7 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_INSERT_PAGENO)
 		MenuItem(AP_MENU_ID_INSERT_DATETIME)
 		MenuItem(AP_MENU_ID_INSERT_FIELD)
+		MenuItem(AP_MENU_ID_INSERT_TEXTBOX)
 		MenuItem(AP_MENU_ID_INSERT_MAILMERGE)
 		MenuItem(AP_MENU_ID_INSERT_SYMBOL)
 
@@ -191,11 +197,12 @@ BeginLayout(Main,0)
 		EndSubMenu()
 
 		Separator()
-		MenuItem(AP_MENU_ID_INSERT_INSERTHEADER)
-		MenuItem(AP_MENU_ID_INSERT_INSERTFOOTER)
+		MenuItem(AP_MENU_ID_INSERT_HEADER)
+		MenuItem(AP_MENU_ID_INSERT_FOOTER)
 		MenuItem(AP_MENU_ID_INSERT_FILE)
 		MenuItem(AP_MENU_ID_INSERT_BOOKMARK)
 		MenuItem(AP_MENU_ID_INSERT_HYPERLINK)
+		MenuItem(AP_MENU_ID_INSERT_TABLEOFCONTENTS)
 		MenuItem(AP_MENU_ID_INSERT_FOOTNOTE)
 		MenuItem(AP_MENU_ID_INSERT_ENDNOTE)
 
@@ -221,6 +228,8 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_FMT_PARAGRAPH)
 		MenuItem(AP_MENU_ID_FMT_BULLETS)
 		MenuItem(AP_MENU_ID_FMT_DOCUMENT)
+		MenuItem(AP_MENU_ID_FMT_FRAME)
+        MenuItem(AP_MENU_ID_FMT_IMAGE)
 #if 0 // someone code and turn this back on
 		MenuItem(AP_MENU_ID_FMT_BORDERS)
 #endif
@@ -229,6 +238,7 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_FMT_TABS)
 		MenuItem(AP_MENU_ID_FMT_HDRFTR)
 		MenuItem(AP_MENU_ID_FMT_FOOTNOTES)
+		MenuItem(AP_MENU_ID_FMT_TABLEOFCONTENTS)
 		Separator()
 		MenuItem(AP_MENU_ID_FMT_TOGGLECASE)
 		Separator()
@@ -255,17 +265,22 @@ BeginLayout(Main,0)
 		BeginSubMenu(AP_MENU_ID_FMT_STYLE)
 			MenuItem(AP_MENU_ID_FMT_STYLE_DEFINE)
 			MenuItem(AP_MENU_ID_FMT_IMPORTSTYLES)
+	        MenuItem(AP_MENU_ID_FMT_STYLIST)
 		EndSubMenu()
 		Separator()
 		MenuItem(AP_MENU_ID_EDIT_REMOVEHEADER)
 		MenuItem(AP_MENU_ID_EDIT_REMOVEFOOTER)
-		MenuItem(AP_MENU_ID_FMT_BACKGROUND)
 
-		BeginSubMenu(AP_MENU_ID_FMT_DIRECTION)
-	        	MenuItem(AP_MENU_ID_FMT_DIRECTION_DD_RTL)
-	        	MenuItem(AP_MENU_ID_FMT_DIRECTION_DO_LTR)
-        		MenuItem(AP_MENU_ID_FMT_DIRECTION_DO_RTL)
-	    	EndSubMenu()
+		BeginSubMenu(AP_MENU_ID_FMT_BACKGROUND)
+		    MenuItem(AP_MENU_ID_FMT_BACKGROUND_PAGE_IMAGE)
+		    MenuItem(AP_MENU_ID_FMT_BACKGROUND_PAGE_COLOR)
+	    EndSubMenu()
+
+	    BeginSubMenu(AP_MENU_ID_FMT_DIRECTION)
+	        MenuItem(AP_MENU_ID_FMT_DIRECTION_DD_RTL)
+        	MenuItem(AP_MENU_ID_FMT_DIRECTION_DO_LTR)
+        	MenuItem(AP_MENU_ID_FMT_DIRECTION_DO_RTL)
+    	EndSubMenu()
 	EndSubMenu()
 
 	BeginSubMenu(AP_MENU_ID_TOOLS)
@@ -279,18 +294,46 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_FMT_LANGUAGE)
 		MenuItem(AP_MENU_ID_TOOLS_WORDCOUNT)
 
+		Separator()
+
+	    BeginSubMenu(AP_MENU_ID_TOOLS_HISTORY)
+	        MenuItem(AP_MENU_ID_TOOLS_HISTORY_SHOW)
+	        MenuItem(AP_MENU_ID_TOOLS_REVISIONS_COMPARE_DOCUMENTS)
+		    MenuItem(AP_MENU_ID_TOOLS_REVISIONS_AUTO)
+		EndSubMenu()
+	
 		BeginSubMenu(AP_MENU_ID_TOOLS_REVISIONS)
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_MARK)
+		    Separator()
+	        MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SHOW)
+			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SHOW_AFTER)
+			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SHOW_AFTERPREV)
+			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SHOW_BEFORE)
+			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SET_VIEW_LEVEL)
+	        Separator()
+			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_FIND_NEXT)
+			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_FIND_PREV)
+	        Separator()
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_ACCEPT_REVISION)
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_REJECT_REVISION)
-			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SET_VIEW_LEVEL)
+#ifdef DEBUG
+	        Separator()
+		    MenuItem(AP_MENU_ID_TOOLS_REVISIONS_MERGE_DOCUMENTS)
+#endif
 		EndSubMenu()
+	
+	    Separator()
 
 		MenuItem(AP_MENU_ID_TOOLS_PLUGINS)
 		MenuItem(AP_MENU_ID_TOOLS_SCRIPTS)
 		MenuItem(AP_MENU_ID_TOOLS_MAILMERGE)
+#ifndef XP_MAC_TARGET_MACOSX
+		// On MacOS X don't put a separator as the "Option" menu item is moved away at run time
+#endif
+#if XAP_PREFSMENU_UNDER_TOOLS
 		Separator()
 		MenuItem(AP_MENU_ID_TOOLS_OPTIONS)
+#endif
 	EndSubMenu()
 
 	BeginSubMenu(AP_MENU_ID_TABLE)
@@ -301,8 +344,10 @@ BeginLayout(Main,0)
 			MenuItem(AP_MENU_ID_TABLE_INSERT_COLUMNS_AFTER)
 			MenuItem(AP_MENU_ID_TABLE_INSERT_ROWS_BEFORE)
 			MenuItem(AP_MENU_ID_TABLE_INSERT_ROWS_AFTER)
+			MenuItem(AP_MENU_ID_TABLE_INSERT_SUMCOLS)
+			MenuItem(AP_MENU_ID_TABLE_INSERT_SUMROWS)
 #if 0
-// Not for 2.0
+// Not for 2.2
 			MenuItem(AP_MENU_ID_TABLE_INSERT_CELLS)
 #endif
 		EndSubMenu()
@@ -312,34 +357,40 @@ BeginLayout(Main,0)
 			MenuItem(AP_MENU_ID_TABLE_DELETE_COLUMNS)
 			MenuItem(AP_MENU_ID_TABLE_DELETE_ROWS)
 #if 0
-// Not for 2.0
+// Not for 2.2
 			MenuItem(AP_MENU_ID_TABLE_DELETE_CELLS)
 #endif
 		EndSubMenu()
 
    		BeginSubMenu(AP_MENU_ID_TABLE_SELECT)
 			MenuItem(AP_MENU_ID_TABLE_SELECT_TABLE)
-#if 0
-// Not for 2.0
 			MenuItem(AP_MENU_ID_TABLE_SELECT_COLUMN)
-#endif
 			MenuItem(AP_MENU_ID_TABLE_SELECT_ROW)
 			MenuItem(AP_MENU_ID_TABLE_SELECT_CELL)
 		EndSubMenu()
 
 		Separator()
 		MenuItem(AP_MENU_ID_TABLE_MERGE_CELLS)
-#if 0
-// Not for 2.0
 		MenuItem(AP_MENU_ID_TABLE_SPLIT_CELLS)
+#if 0
+// Not for 2.2
 		MenuItem(AP_MENU_ID_TABLE_SPLIT_TABLE)
 #endif
 		MenuItem(AP_MENU_ID_TABLE_FORMAT)
-#if 0
-// Not for 2.0
+		MenuItem(AP_MENU_ID_TABLE_TEXTTOTABLE)
+#if DEBUG
+	    BeginSubMenu(AP_MENU_ID_TABLE_SORT)
+	       MenuItem(AP_MENU_ID_TABLE_SORTROWSASCEND)
+	       MenuItem(AP_MENU_ID_TABLE_SORTROWSDESCEND)
+	       MenuItem(AP_MENU_ID_TABLE_SORTCOLSASCEND)
+	       MenuItem(AP_MENU_ID_TABLE_SORTCOLSDESCEND)
+	    EndSubMenu()
+#endif
 		MenuItem(AP_MENU_ID_TABLE_AUTOFIT)
+
+#if 0
+// Not for 2.2
 		MenuItem(AP_MENU_ID_TABLE_HEADING_ROWS_REPEAT)
-		MenuItem(AP_MENU_ID_TABLE_SORT)
 #endif
 	EndSubMenu()
 
@@ -373,7 +424,10 @@ BeginLayout(Main,0)
 		Separator()
 #ifndef HAVE_GNOME
 		MenuItem(AP_MENU_ID_HELP_CREDITS)
+#ifndef XP_MAC_TARGET_MACOSX
+		// On MacOS X don't put a separator as the "About" menu item is moved away at run time
 		Separator()
+#endif
 #endif
 		MenuItem(AP_MENU_ID_HELP_ABOUT)
 	EndSubMenu()
